@@ -3,14 +3,9 @@ use std::hash::Hash;
 
 use crate::cache::InsertionPolicy;
 
+#[derive(Default)]
 pub struct AlwaysInsertPolicy {}
 
-impl Default for AlwaysInsertPolicy {
-    fn default() -> Self {
-        AlwaysInsertPolicy {}
-    }
-}
-
 impl<K> InsertionPolicy<K> for AlwaysInsertPolicy {
     fn should_add(&mut self, _key: &K) -> bool {
         true
